---
title: TimeSeries
type: tags
order: 307
---

TimeSeries tag can be used to label time series data.
Read more about Time Series Labeling on [template page](../templates/time_series.html).

### Parameters

| Param | Type | Description |
| --- | --- | --- |
| name | <code>string</code> | name of the element |
| value | <code>string</code> | key used to lookup the data, it needs to reference either URLs for your time-series if valueType=url, otherwise expects JSON |
| [valueType] | <code>enum</code> | "url" or "json" If set to "url" then it loads value references inside `value` key, otherwise it expects JSON. Defaults to url |
| [timeColumn] | <code>string</code> | column name or index that provides temporal values, if your time-series data has no temporal column then its automatically generated |
| [timeFormat] | <code>string</code> | pattern used to parse values inside timeColumn, parsing provided by d3, and follows `strftime` implementation |
| [timeDisplayFormat] | <code>string</code> | format used to display temporal value, can be a number or a date, if a temporal column is a date then use strftime to format it, otherwise, if it's a number then use [d3 number](https://github.com/d3/d3-format#locale_format) formatting |
| [sep] | <code>string</code> | separator for you CSV file, default is comma "," |
| [overviewChannels] | <code>string</code> | comma-separated list of channels names or indexes displayed in overview |

## Channel

Channel tag can be used to label time series data

### Parameters

| Param | Type | Default | Description |
| --- | --- | --- | --- |
| column | <code>string</code> |  | column name or index |
| [legend] | <code>string</code> |  | display name of the channel |
| [units] | <code>string</code> |  | display units name |
| [displayFormat] | <code>string</code> |  | format string for the values, uses d3-format:<br/>        `[,][.precision][f\|%]`<br/>        `,` - group thousands with separator (from locale): `,` (12345.6 -> 12,345.6) `,.2f` (12345.6 -> 12,345.60)<br/>        `.precision` - precision for `f\|%` type, significant digits for empty type:<br/>                     `.3f` (12.3456 -> 12.345, 1000 -> 1000.000)<br/>                     `.3` (12.3456 -> 12.3, 1.2345 -> 1.23, 12345 -> 1.23e+4)<br/>        `f` - treat as float, default precision is .6: `f` (12 -> 12.000000) `.2f` (12 -> 12.00) `.0f` (12.34 -> 12)<br/>        `%` - treat as percents and format accordingly: `%.0` (0.128 -> 13%) `%.1` (1.2345 -> 123.4%) |
| [height] | <code>number</code> |  | height of the plot |
| [strokeColor] | <code>string</code> | <code>&quot;#f48a42&quot;</code> | plot stroke color, expects hex value |
| [strokeWidth] | <code>number</code> | <code>1</code> | plot stroke width |


### Example

csv loaded by url in `value` with 3 columns: time, sensor1, sensor2

```html
<!-- key column `time` is a number actually -->
<View>
  <TimeSeries name="device" value="$timeseries" valueType="url" timeColumn="time">
     <Channel column="sensor1" />
     <Channel column="sensor2" />
  </TimeSeries>
</View>
```
### Example

data stored directly in task's field `ts` as json

```html
<!-- timeseries key (`time`) is date in `timeFormat` formatted as full date on plot (by default) -->
<View>
  <TimeSeries name="device" value="$ts" timeColumn="time" timeFormat="%m/%d/%Y %H:%M:%S">
     <Channel column="sensor1" />
     <Channel column="sensor2" />
  </TimeSeries>
</View>
```
